@@ -5,7 +5,7 @@
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
- * $Id: vfuopt.cpp,v 1.14 2003/04/28 17:17:01 cade Exp $
+ * $Id: vfuopt.cpp,v 1.16 2004/07/08 01:25:52 cade Exp $
  *
  */
 
@@ -349,6 +349,7 @@ void vfu_settings_load()
       if(set_arr( line, "archive",  archive_extensions))continue;
       
       if(set_str( line, "editor", shell_editor))continue;
+      if(set_str( line, "diff",   shell_diff))continue;
       
       if(set_arr( line, "bookmark",  path_bookmarks))continue;
       // follow 10 are deprecated
@@ -471,11 +472,15 @@ void vfu_edit_conf_file()
 
 void vfu_options()
 {
+  say1("press SPACE to toggle, ENTER or ESC to exit");
+  say2("");
   vfu_toggle_box( 30, 5, "Options/Toggles   (scroll down...)", Toggles );
   vfu_settings_save();
   vfu_settings_load();
   vfu_drop_all_views();
   vfu_redraw(); 
   vfu_redraw_status();
+  say1("");
+  say2("");
 };
 
