@@ -1,10 +1,13 @@
 /*
  *
- * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-1999
+ * (c) Vladi Belperchinov-Shabanski "Cade" <cade@biscom.net> 1998-2003
  *
  * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
  *
+ * $Id: clusters.cpp,v 1.5 2003/01/21 19:56:35 cade Exp $
+ *
  */
+
 #include <stdlib.h>
 #include <string.h>
 #include "clusters.h"
@@ -323,7 +326,7 @@ void FLCluster::dump()
       
     BSet::~BSet() 
       { 
-      free( data ); 
+      if( data ) free( data );
       };
 
     void BSet::set1( int pn )
@@ -451,130 +454,4 @@ void FLCluster::dump()
       return b;
     };
     
-/****************************************************************************
-**
-** V cluster (this is a versatile cluster that holds data as strings)
-**
-****************************************************************************/
-
-    int PSZCluster::add( const char* pe )
-    {
-      RETURN(ins( cnt, pe ));
-    };
-
-    int PSZCluster::ins( int pn, const char* pe )
-    {
-      size_t slen = strlen( pe );
-      if ( slen > max_str_len ) max_str_len = slen;
-      if ( slen < min_str_len ) min_str_len = slen;
-      char* newstr = new char[slen + 1];
-      strcpy( newstr, pe );
-      RETURN(PCluster::ins( pn, newstr ));
-    };
-
-    void PSZCluster::put( int pn, const char* pe )
-    {
-      ASSERT( pn >= 0 && pn < cnt );
-      free( pn );
-      ins( pn, pe );
-    };
-
-    void PSZCluster::get( int pn, char* pe )
-    {
-      ASSERT( pn >= 0 && pn < cnt );
-      strcpy( pe, (char*)((void**)data)[pn] );
-    };
-
-    char* PSZCluster::get( int pn )
-    {
-      ASSERT( pn >= 0 && pn < cnt );
-      return (char*)((void**)data)[pn];
-    };
-
-    void PSZCluster::sort( int ascending = 1 )
-    {
-      if ( count() > 1 )
-        q_sort( 0, count() - 1 );
-    };
-    
-    void PSZCluster::q_sort( int lo, int hi )
-    {
-      int m, l, r;
-      const char* v;
-      
-      m = ( hi + lo ) / 2;
-      v = (char*)((void**)data)[m];
-      l = lo;
-      r = hi;
-      
-      do
-        {
-        while( (l <= hi) && (strcmp((char*)((void**)data)[l],v) < 0) ) l++;
-        while( (r >= lo) && (strcmp(v,(char*)((void**)data)[r]) < 0) ) r--;
-        if ( l <= r )
-          {
-          char *t;
-          t = (char*)((void**)data)[l];
-          ((void**)data)[l] = (char*)((void**)data)[r];
-          ((void**)data)[r] = t;
-          l++;
-          r--;
-          }
-        }
-      while( l <= r );
-      
-      if ( lo < r ) q_sort( lo, r );
-      if ( l < hi ) q_sort( l, hi );
-    };
-    
-
-////////////////////////////////////////////////////////////////////////////
-//
-// misc support functions
-//
-
-int SaveToFile( FILE *f, PSZCluster *szc )
-{
-  int z;
-  for(z = 0; z < szc->count(); z++)
-    {
-    size_t len = strlen(szc->get(z));
-    if (fwrite( szc->get(z), 1, len, f ) != len) return -1;
-    if (fwrite( "\n", 1, 1, f ) != 1) return -1;
-    }
-  return 0;
-}
-
-int SaveToFile( const char *fname, PSZCluster *szc )
-{
-  FILE *f = fopen( fname, "wt" );
-  if (!f) return -1;
-  int res = SaveToFile( f, szc );
-  fclose(f);
-  return res;
-}
-
-int LoadFromFile( FILE *f, PSZCluster *szc, size_t maxlen )
-{
-  char *buff = new char[maxlen+1];
-  while(fgets( buff, maxlen, f ))
-    {
-    int slen = strlen( buff );
-    if (buff[slen-1] == '\n') buff[slen-1] = 0;
-    szc->add( buff );
-    }
-  return 0;
-}
-
-int LoadFromFile( const char *fname, PSZCluster *szc, size_t maxlen )
-{
-  FILE *f = fopen( fname, "rt" );
-  if (!f) return -1;
-  int res = LoadFromFile( f, szc, maxlen );
-  fclose(f);
-  return res;
-}
-
-////////////////////////////////////////////////////////////////////////////
-
 // eof
